@@ -18,7 +18,9 @@ enum KernelType {
 
 enum StatsType {
     CONDITION_DISTANCE_COVARIANCE = 1,
-    CONDITION_DISTANCE_CORRELATION = 2
+    CONDITION_DISTANCE_CORRELATION = 2,
+    CONDITION_BALL_COVARIANCE = 3,
+    CONDITION_BALL_CORRELATION = 4
 };
 
 enum StatsMethod {
